==> util-1.0.1-sources.jar: android/library/util/recyclerview/BaseViewAdapter.java <==
package android.library.util.recyclerview;

import android.content.Context;
import android.view.LayoutInflater;
import android.view.ViewGroup;

import androidx.recyclerview.widget.RecyclerView;

import java.util.List;

/**
 * recyclerView封装
 *
 * @param <T> 数据源范型
 */
public abstract class BaseViewAdapter<T> extends RecyclerView.Adapter<BaseViewHolder> {

    private List<T> list;
    private int layoutId;
    /**
     * item点击监听
     */
    private OnItemClickListener onItemClickListener;
    /**
     * item中子View点击监听
     */
    private OnChildClickListener onChildClickListener;

    private RecyclerView recyclerView;

    public BaseViewAdapter(List<T> list, int layoutId) {
        this.list = list;
        this.layoutId = layoutId;
    }

    public BaseViewAdapter(List<T> list, int layoutId, OnChildClickListener onChildClickListener) {
        this.list = list;
        this.layoutId = layoutId;
        this.onChildClickListener = onChildClickListener;
    }

    @Override
    public BaseViewHolder onCreateViewHolder(ViewGroup parent, int viewType) {
        return new BaseViewHolder(LayoutInflater.from(recyclerView.getContext()).inflate(layoutId, parent, false), onChildClickListener);
    }

    @Override
    public void onBindViewHolder(BaseViewHolder holder, int position) {
        holder.setItemPosition(position);
        if (onItemClickListener != null) {
            holder.itemView.setOnClickListener(new OnItemViewClickListener(onItemClickListener, position));
        }
        onBind(list.get(position), position, holder);
    }

    @Override
    public void onAttachedToRecyclerView(RecyclerView recyclerView) {
        this.recyclerView = recyclerView;
    }

    /**
     * item数据绑定
     *
     * @param bean     当前item对应的数据
     * @param position 当前下标
     * @param ho       viewHolder
     */
    public abstract void onBind(T bean, int position, BaseViewHolder ho);

    @Override
    public int getItemCount() {
        return list.size();
    }

    public Context getContext() {
        return recyclerView.getContext();
    }

    /**
     * item的点击事件
     *
     * @param onItemClickListener 回调监听
     */
    public void setOnItemClickListener(OnItemClickListener onItemClickListener) {
        this.onItemClickListener = onItemClickListener;
    }

    /**
     * item中子View的点击事件
     *
     * @param onChildClickListener 回调监听
     */
    public void setOnChildClickListener(OnChildClickListener onChildClickListener) {
        this.onChildClickListener = onChildClickListener;
    }

    /**
     * item中子控件的点击事件回调
     */
    public interface OnChildClickListener {
        void onChildClick(int position, int id);
    }

    /**
     * item点击事件回调
     */
    public interface OnItemClickListener {
        void onItemClick(int position);
    }

    /**
     * @param position 当前下标
     * @return 当前下标对应的数据
     */
    public T getItemBeen(int position) {
        return list.get(position);
    }
}

==> util-1.0.5-sources.jar: android/library/util/recyclerview/BaseViewAdapter.java <==
package android.library.util.recyclerview;

import android.content.Context;
import android.view.LayoutInflater;
import android.view.View;
import android.view.ViewGroup;

import androidx.recyclerview.widget.RecyclerView;

import java.util.ArrayList;

/**
 * recyclerView封装
 *
 * @param <T> 数据源范型
 */
public abstract class BaseViewAdapter<T> extends RecyclerView.Adapter<BaseViewHolder> {

    private ArrayList<T> list;
    private int layoutId;
    /**
     * item点击监听
     */
    private OnItemClickListener onItemClickListener;
    /**
     * item中子View点击监听
     */
    private OnChildClickListener onChildClickListener;

    private RecyclerView recyclerView;

    public BaseViewAdapter(ArrayList<T> list, int layoutId) {
        this.list = list;
        this.layoutId = layoutId;
    }

    public BaseViewAdapter(ArrayList<T> list, int layoutId, OnChildClickListener onChildClickListener) {
        this.list = list;
        this.layoutId = layoutId;
        this.onChildClickListener = onChildClickListener;
    }

    @Override
    public BaseViewHolder onCreateViewHolder(ViewGroup parent, int viewType) {
        View view = LayoutInflater.from(recyclerView.getContext()).inflate(layoutId, parent, false);
        BaseViewHolder baseViewHolder = new BaseViewHolder(view, onChildClickListener);
        if (onItemClickListener != null) {
            baseViewHolder.itemView.setOnClickListener(new OnItemViewClickListener(onItemClickListener, baseViewHolder.getLayoutPosition()));
        }
        return baseViewHolder;
    }

    @Override
    public void onBindViewHolder(BaseViewHolder holder, int position) {
        onBind(list.get(position), position, holder);
    }

    @Override
    public void onAttachedToRecyclerView(RecyclerView recyclerView) {
        this.recyclerView = recyclerView;
    }

    /**
     * item数据绑定
     *
     * @param bean     当前item对应的数据
     * @param position 当前下标
     * @param ho       viewHolder
     */
    public abstract void onBind(T bean, int position, BaseViewHolder ho);

    @Override
    public int getItemCount() {
        return list.size();
    }

    public Context getContext() {
        return recyclerView.getContext();
    }

    /**
     * item的点击事件
     *
     * @param onItemClickListener 回调监听
     */
    public void setOnItemClickListener(OnItemClickListener onItemClickListener) {
        this.onItemClickListener = onItemClickListener;
    }

    /**
     * item中子View的点击事件
     *
     * @param onChildClickListener 回调监听
     */
    public void setOnChildClickListener(OnChildClickListener onChildClickListener) {
        this.onChildClickListener = onChildClickListener;
    }

    /**
     * item中子控件的点击事件回调
     */
    public interface OnChildClickListener {
        void onChildClick(int position, int id);
    }

    /**
     * item点击事件回调
     */
    public interface OnItemClickListener {
        void onItemClick(int position);
    }

    /**
     * @param position 当前下标
     * @return 当前下标对应的数据
     */
    public T getItemBeen(int position) {
        return list.get(position);
    }
}
